function plot_bm(obj, show_text, speed)
%Plots a bm object as a sequence
%  Requires BioMotion toolbox in the search path

switch nargin
    case 0
        error('Need BioMotion object');
    case 1
        show_text = true;
        speed = 1;
    case 2
        speed = 1;
end

Range = @(x) [min(x), max(x)];

bm = obj.Copy;

% joint text to overlay
joint_num_display = arrayfun(@(x) sprintf('%d', x), 0:bm.nPointLights, 'uni', false);

data = bm.NormJointsInfo;

% xyz coordinate data
x = data(:,:,1);
y = data(:,:,2);
z = data(:,:,3);

% center coords
x = x - mean(Range(mean(x, 2)));
y = y - mean(Range(mean(y, 2)));
z = z - mean(Range(mean(z, 2)));

% min and max coordinates for each frame each axis
xlen = mean(abs(max(x, [], 1) - min(x, [], 1)));
ylen = mean(abs(max(y, [], 1) - min(y, [], 1)));
zlen = mean(abs(max(z, [], 1) - min(z, [], 1)));

% normalize
x = x ./ max(abs(x(:)));
y = y ./ max(abs(y(:)));
z = z ./ max(abs(z(:)));

% keep aspect ratio based on y coord
x = x .* (xlen/ylen);
z = z .* (zlen/ylen);

x0 = x(:, 1);
y0 = y(:, 1);
z0 = z(:, 1);
    
% open figure window
act_fig = figure;
set(act_fig, 'units','normalized','OuterPosition',[0.1 0.1 0.4 0.6]);
set(act_fig, 'MenuBar', 'none');
set(act_fig, 'ToolBar', 'none');
set(act_fig, 'Name', '  BM Display ');
set(act_fig, 'color', [0.15 0.15 0.15]);

for i = round(1:speed:bm.nFrames)
    % xyz coords for each joint for current frame

    xp = x(:, i);
    yp = y(:, i);
    zp = z(:, i);
    
    pause(0.001);
    
    % start plotting
    if ishandle(act_fig)
        scatter3(xp, yp, zp, 75 + (50 .* zp), [0.85, 0.85, 0.85], 'filled');
        hold on
        view(0, 90);
        if show_text
            joint_num_display{1} = num2str(i);
            t = text([-1; xp], [1; yp], [0; zp], joint_num_display);
            set(t, 'Color', 'red', 'Fontsize', 10, ...
                'horizontalAlignment', 'center', 'FontWeight', 'bold', ...
                'Interpreter', 'none', 'Interruptible', 'off', ...
                'PickableParts', 'none','HitTest','off', 'FontSmoothing', 'off');
        end
        axis off;
        axis([-1.05, 1.05, -1.05, 1.05, -1.05, 1.05]);
        hold off;
    else
        break
    end
end

if ishandle(act_fig)
    clf(act_fig);
    close(act_fig);
end

end
